:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _thirdparty:

Third Party Applications
========================

A list of Third-Party Applications compatible with |grappelli|.


Django FileBrowser
------------------

No additional setup is needed when installing the `Django FileBrowser <http://code.google.com/p/django-filebrowser/>`_ with Grappelli.
